@@ -1,5 +1,25 @@
 /* -*- indent-tabs-mode: t; tab-width: 8; c-basic-offset: 8; -*- */
 
+
+/* ts A71019 */
+
+/* Standard measure should be: Threads are created detached.
+   According to the man pages they should then care for disposing themselves.
+
+   >>> ??? It is yet unclear why the threads vanish from the process list
+           even if joinable and even if never joined.
+
+   To be activated after release of libburn-0.4.0
+*/
+#define Libburn_create_detached_threadS 1
+
+/* Alternative : Threads are created joinable.
+   Threads get detached in remove_worker() and thus should dispose themselves.
+
+#define Libburn_detach_done_workeR 1
+*/
+
+
 #include "libburn.h"
 #include "transport.h"
 #include "drive.h"
@@ -7,9 +27,12 @@
 #include "options.h"
 #include "async.h"
 #include "init.h"
+#include "file.h"
 #include "back_hacks.h"
 
 #include <pthread.h>
+#include <sys/types.h>
+#include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -53,6 +76,12 @@ struct write_opts
 	struct burn_disc *disc;
 };
 
+struct fifo_opts
+{
+	struct burn_source *source;
+	int flag;
+};
+
 
 struct w_list
 {
@@ -67,10 +96,12 @@ struct w_list
 		struct erase_opts erase;
 		struct format_opts format;
 		struct write_opts write;
+		struct fifo_opts fifo;
 	} u;
 };
 
-static struct w_list *workers;
+static struct w_list *workers = NULL;
+
 
 static struct w_list *find_worker(struct burn_drive *d)
 {
@@ -86,6 +117,11 @@ static void add_worker(struct burn_drive *d, WorkerFunc f, void *data)
 {
 	struct w_list *a;
 	struct w_list *tmp;
+	pthread_attr_t *attr_pt = NULL;
+
+#ifdef Libburn_create_detached_threadS
+	pthread_attr_t attr;
+#endif
 
 	a = malloc(sizeof(struct w_list));
 	a->drive = d;
@@ -96,26 +132,65 @@ static void add_worker(struct burn_drive *d, WorkerFunc f, void *data)
 	tmp = workers;
 	workers = a;
 
-	if (d)
+	if (d != NULL)
 		d->busy = BURN_DRIVE_SPAWNING;
 
-	if (pthread_create(&a->thread, NULL, f, a)) {
+#ifdef Libburn_create_detached_threadS
+	/* ts A71019 :
+	   Trying to start the threads detached to get rid of the zombies
+	   which do neither react on pthread_join() nor on pthread_detach().
+	*/
+	pthread_attr_init(&attr);
+	pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_DETACHED);
+	attr_pt= &attr;
+/*
+	libdax_msgs_submit(libdax_messenger, -1, 0x00020158,
+			LIBDAX_MSGS_SEV_DEBUG, LIBDAX_MSGS_PRIO_LOW,
+			"add_worker(): Creating detached thread.", 0, 0);
+*/
+#endif
+
+	if (pthread_create(&a->thread, attr_pt, f, a)) {
 		free(a);
 		workers = tmp;
 		return;
 	}
 }
 
+
 static void remove_worker(pthread_t th)
 {
 	struct w_list *a, *l = NULL;
 
+#ifdef Libburn_detach_done_workeR
+	int ret;
+	char msg[80];
+#endif
+
 	for (a = workers; a; l = a, a = a->next)
 		if (a->thread == th) {
 			if (l)
 				l->next = a->next;
 			else
 				workers = a->next;
+
+#ifdef Libburn_detach_done_workeR
+			/* ts A71019 : burry dead puppy before forgetting it */
+			/* Alternative : threads get detached and thus should
+					dispose themselves.
+			*/
+			ret = pthread_detach(th);
+/*
+			sprintf(msg,
+			 "remove_workers(): pid= %lu  pthread_detach(%lu)= %d",
+			 (unsigned long) getpid(), (unsigned long) th, ret);
+			libdax_msgs_submit(libdax_messenger, -1, 0x00020158,
+				LIBDAX_MSGS_SEV_DEBUG, LIBDAX_MSGS_PRIO_LOW,
+				msg, 0, 0);
+*/
+			
+#endif /* Libburn_detach_done_workeR */
+
 			free(a);
 			break;
 		}
@@ -130,8 +205,13 @@ static void remove_worker(pthread_t th)
 
 static void *scan_worker_func(struct w_list *w)
 {
-	burn_drive_scan_sync(w->u.scan.drives, w->u.scan.n_drives);
-	w->u.scan.done = 1;
+	int ret;
+
+	ret = burn_drive_scan_sync(w->u.scan.drives, w->u.scan.n_drives, 1);
+	if (ret <= 0)
+		w->u.scan.done = -1;
+	else
+		w->u.scan.done = 1;
 	return NULL;
 }
 
@@ -165,12 +245,13 @@ drive_is_active:;
 		return -1;
 	}
 
-	if (!workers) {
+	if (workers == NULL) {
 		/* start it */
 
 		/* ts A61007 : test moved up from burn_drive_scan_sync()
 				was burn_wait_all() */
-		if (!burn_drives_are_clear())
+		/* ts A70907 : now demanding freed drives, not only released */
+		if (!burn_drives_are_clear(1))
 			goto drive_is_active;
 		*drives = NULL;
 		*n_drives = 0;
@@ -189,7 +270,7 @@ drive_is_active:;
 		if (workers != NULL) {
 			libdax_msgs_submit(libdax_messenger, -1, 0x00020101,
 				LIBDAX_MSGS_SEV_WARNING, LIBDAX_MSGS_PRIO_HIGH,
-			     "After scan a  drive operation is still going on",
+			     "After scan a drive operation is still going on",
 				0, 0);
 			return -1;
 		}
@@ -211,9 +292,6 @@ void burn_disc_erase(struct burn_drive *drive, int fast)
 {
 	struct erase_opts o;
 
-	/* A70103 : will be set to 0 by burn_disc_erase_sync() */
-	drive->cancel = 1;
-
 	/* ts A61006 */
 	/* a ssert(drive); */
 	/* a ssert(!SCAN_GOING()); */
@@ -233,12 +311,17 @@ void burn_disc_erase(struct burn_drive *drive, int fast)
 			0, 0);
 		return;
 	}
+	/* A70103 : will be set to 0 by burn_disc_erase_sync() */
+	drive->cancel = 1;
 
 	/* ts A70103 moved up from burn_disc_erase_sync() */
 	/* ts A60825 : allow on parole to blank appendable CDs */
 	/* ts A70131 : allow blanking of overwriteable DVD-RW (profile 0x13) */
 	/* ts A70216 : allow blanking of CD-RW or DVD-RW in any regular state
 	               and of any kind of full media */
+	/* ts A70909 : the willingness to burn any BURN_DISC_FULL media is
+	               inappropriate. One would rather need a -force option
+	               Note: keep this in sync with mmc_read_disc_info() */
 	if ((drive->current_profile != 0x0a &&
 	     drive->current_profile != 0x13 &&
 	     drive->current_profile != 0x14 &&
@@ -247,6 +330,8 @@ void burn_disc_erase(struct burn_drive *drive, int fast)
 	    (drive->status != BURN_DISC_FULL &&
 	     drive->status != BURN_DISC_APPENDABLE &&
 	     drive->status != BURN_DISC_BLANK)
+	    ||
+	    (drive->drive_role != 1)
 	   ) {
 		libdax_msgs_submit(libdax_messenger, drive->global_index,
 			0x00020130,
@@ -287,6 +372,14 @@ void burn_disc_format(struct burn_drive *drive, off_t size, int flag)
 			0, 0);
 		return;
 	}
+	if (drive->drive_role != 1) {
+		libdax_msgs_submit(libdax_messenger, drive->global_index,
+			0x00020146,
+			LIBDAX_MSGS_SEV_FATAL, LIBDAX_MSGS_PRIO_HIGH,
+			"Drive is a virtual placeholder", 0, 0);
+		drive->cancel = 1;
+		return;
+	}
 	if (flag & 128)     /* application prescribed format type */
 		flag |= 16; /* enforce re-format */
 
@@ -320,7 +413,13 @@ void burn_disc_format(struct burn_drive *drive, off_t size, int flag)
 
 static void *write_disc_worker_func(struct w_list *w)
 {
+	struct burn_drive *d = w->u.write.drive;
+
+	d->thread_pid = getpid();
+	d->thread_pid_valid= 1;
 	burn_disc_write_sync(w->u.write.opts, w->u.write.disc);
+	d->thread_pid_valid= 0;
+	d->thread_pid = 0;
 
 	/* the options are refcounted, free out ref count which we added below 
 	 */
@@ -334,17 +433,6 @@ void burn_disc_write(struct burn_write_opts *opts, struct burn_disc *disc)
 {
 	struct write_opts o;
 	char reasons[BURN_REASONS_LEN+80];
-#ifndef Libburn_precheck_write_ruleS
-	int i, j, mode, mixed_mode = 0;
-#endif
-
-
-	/* For the next lines any return indicates failure */
-	opts->drive->cancel = 1;
-
-	/* ts A70203 : people have been warned in API specs */
-	if (opts->write_type == BURN_WRITE_NONE)
-		return;
 
 	/* ts A61006 */
 	/* a ssert(!SCAN_GOING()); */
@@ -357,8 +445,24 @@ void burn_disc_write(struct burn_write_opts *opts, struct burn_disc *disc)
 			0, 0);
 		return;
 	}
+
+	/* For the next lines any return indicates failure */
+	opts->drive->cancel = 1;
+
+	/* ts A70203 : people have been warned in API specs */
+	if (opts->write_type == BURN_WRITE_NONE)
+		return;
+
+	if (opts->drive->drive_role == 0) {
+		libdax_msgs_submit(libdax_messenger, opts->drive->global_index,
+			0x00020146,
+			LIBDAX_MSGS_SEV_FATAL, LIBDAX_MSGS_PRIO_HIGH,
+			"Drive is a virtual placeholder (null-drive)", 0, 0);
+		return;
+	}
+
 	/* ts A61007 : obsolete Assert in spc_select_write_params() */
-	if (!opts->drive->mdata->valid) {
+	if (opts->drive->drive_role == 1 && !opts->drive->mdata->valid) {
 		libdax_msgs_submit(libdax_messenger,
 				opts->drive->global_index, 0x00020113,
 				LIBDAX_MSGS_SEV_SORRY, LIBDAX_MSGS_PRIO_HIGH,
@@ -372,48 +476,13 @@ void burn_disc_write(struct burn_write_opts *opts, struct burn_disc *disc)
 	strcpy(reasons, "Write job parameters are unsuitable:\n");
 	if (burn_precheck_write(opts, disc, reasons + strlen(reasons), 1)
 	     == BURN_WRITE_NONE) {
-
-#ifndef Libburn_precheck_write_ruleS
-		libdax_msgs_submit(libdax_messenger,
-				opts->drive->global_index, 0x00020139,
-				LIBDAX_MSGS_SEV_WARNING, LIBDAX_MSGS_PRIO_HIGH,
-				reasons, 0, 0);
-#else
 		libdax_msgs_submit(libdax_messenger,
 				opts->drive->global_index, 0x00020139,
 				LIBDAX_MSGS_SEV_SORRY, LIBDAX_MSGS_PRIO_HIGH,
 				reasons, 0, 0);
 		return;
-#endif /* Libburn_precheck_write_ruleS */
-
 	}
 
-
-#ifndef Libburn_precheck_write_ruleS
-	/* <<< covered burn_precheck_write() */
-	/* ts A61009 : obsolete Assert in sector_headers() */
-	if (! burn_disc_write_is_ok(opts, disc, 0)) /* issues own msgs */
-		return;
-
-	/* <<< covered burn_precheck_write() */
-	/* ts A70122 : libburn SAO code mishandles mode changes */
-	for (i = 0; i < disc->sessions; i++) {
-		if (disc->session[i]->tracks <= 0)
-	continue;
-		mode =  disc->session[i]->track[0]->mode;
-		for (j = 1; j < disc->session[i]->tracks; j++)
-			if (mode != disc->session[i]->track[j]->mode)
-				mixed_mode = 1;
-	}
-	if (mixed_mode && opts->write_type == BURN_WRITE_SAO) {
-		libdax_msgs_submit(libdax_messenger,
-				opts->drive->global_index, 0x00020133,
-				LIBDAX_MSGS_SEV_SORRY, LIBDAX_MSGS_PRIO_HIGH,
-				"Cannot mix data and audio in SAO mode", 0, 0);
-		return;
-	}
-#endif /* ! Libburn_precheck_write_ruleS */
-
 	opts->drive->cancel = 0; /* End of the return = failure area */
 
 	o.drive = opts->drive;
@@ -425,6 +494,40 @@ void burn_disc_write(struct burn_write_opts *opts, struct burn_disc *disc)
 	add_worker(opts->drive, (WorkerFunc) write_disc_worker_func, &o);
 }
 
+
+static void *fifo_worker_func(struct w_list *w)
+{
+	burn_fifo_source_shoveller(w->u.fifo.source, w->u.fifo.flag);
+	remove_worker(pthread_self());
+	return NULL;
+}
+
+
+int burn_fifo_start(struct burn_source *source, int flag)
+{
+	struct fifo_opts o;
+	struct burn_source_fifo *fs = source->data;
+
+	fs->is_started = -1;
+
+	/* create and set up ring buffer */;
+	fs->buf = calloc(fs->chunksize, fs->chunks);
+	if (fs->buf == NULL) {
+		/* >>> could not start ring buffer */;
+		return -1;
+	}
+
+	o.source = source;
+	o.flag = flag;
+	add_worker(NULL, (WorkerFunc) fifo_worker_func, &o);
+	fs->is_started = 1;
+	return 1;
+}
+
+
+#ifdef Libburn_has_burn_async_join_alL
+
+/* ts A71019 : never used */
 void burn_async_join_all(void)
 {
 	void *ret;
@@ -432,3 +535,7 @@ void burn_async_join_all(void)
 	while (workers)
 		pthread_join(workers->thread, &ret);
 }
+
+#endif /* Libburn_has_burn_async_join_alL */
+
+
