@@ -6,6 +6,8 @@
 
 #include <stdarg.h>
 #include <stdio.h>
+#include "libburn.h"
+#include "debug.h"
 
 static int burn_verbosity = 0;
 
@@ -14,7 +16,7 @@ void burn_set_verbosity(int v)
 	burn_verbosity = v;
 }
 
-void burn_print(int level, char *a, ...)
+void burn_print(int level, const char *a, ...)
 {
 #ifdef WIN32
 	char debug_string_data[256];
