@@ -43,7 +43,8 @@ unsigned int burn_drive_count(void);
 
 /* ts A61007 */
 /* void burn_wait_all(void); */
-int burn_drives_are_clear(void);
+/* @param flag  bit0= demand freed drives (else released drives) */
+int burn_drives_are_clear(int flag);
 
 int burn_sector_length_write(struct burn_drive *d);
 int burn_track_control(struct burn_drive *d, int);
@@ -52,8 +53,10 @@ void burn_write_empty_subcode(int fd);
 void burn_drive_free(struct burn_drive *d);
 void burn_drive_free_all(void);
 
+/* @param flag bit0= reset global drive list */
 int burn_drive_scan_sync(struct burn_drive_info *drives[],
-			 unsigned int *n_drives);
+			 unsigned int *n_drives, int flag);
+
 void burn_disc_erase_sync(struct burn_drive *d, int fast);
 int burn_drive_get_block_types(struct burn_drive *d,
 			       enum burn_write_types write_type);
@@ -111,4 +114,15 @@ int burn_disc_get_write_mode_demands(struct burn_disc *disc,
 			struct burn_write_opts *opts,
 			struct burn_disc_mode_demands *result, int flag);
 
+
+/* ts A70924 : convert a special stdio address into fd number.
+   @return >0 is a valid fd , -1 indicates unsuitable address string. 
+*/
+int burn_drive__fd_from_special_adr(char *adr);
+
+
+/* ts A70929 : Find the drive which is being worked on by pid */
+int burn_drive_find_by_thread_pid(struct burn_drive **d, pid_t pid);
+
+
 #endif /* __DRIVE */
