@@ -642,7 +642,7 @@ struct burn_speed_descriptor {
     This must be called before using any other functions in the library. It
     may be called more than once with no effect.
     It is possible to 'restart' the library by shutting it down and
-    re-initializing it. This is necessary if you follow the older and
+    re-initializing it. Once this was necessary if you follow the older and
     more general way of accessing a drive via burn_drive_scan() and
     burn_drive_grab(). See burn_drive_scan_and_grab() with its strong
     urges and its explanations.
@@ -730,7 +730,7 @@ void burn_preset_device_open(int exclusive, int blocking, int abort_on_busy);
 /** Allows the use of media types which are implemented in libburn but not yet
     tested. The list of those untested profiles is subject to change.
     Currently it contains: 0x15 "DVD-R/DL sequential recording",
-                           0x2b "DVD+R/DL"
+                           0x43 "BD-RE"
     If you really test such media, then please report the outcome on
     libburn-hackers@pykix.org
     If ever then this call should be done soon after burn_initialize() before
@@ -809,8 +809,7 @@ void burn_allow_untested_profiles(int yes);
                   (cdrom/burner). Thus use with driveno 0 only. On failure
                   the array has no valid elements at all.
                   The returned array should be freed via burn_drive_info_free()
-                  when it is no longer needed, and before calling a scan
-                  function again.
+                  when it is no longer needed.
                   This is a result from call burn_drive_scan(). See there.
                   Use with driveno 0 only.
     @param adr    The persistent address of the desired drive. Either once
@@ -1094,10 +1093,11 @@ off_t burn_disc_available_space(struct burn_drive *d,
     0x09 "CD-R",                          0x0a "CD-RW",
     0x11 "DVD-R sequential recording",    0x12 "DVD-RAM",
     0x13 "DVD-RW restricted overwrite",   0x14 "DVD-RW sequential recording",
-    0x1a "DVD+RW",                        0x1b "DVD+R".
+    0x1a "DVD+RW",                        0x1b "DVD+R"
+    0x2b "DVD+R/DL"
     If enabled by burn_allow_untested_profiles() it also writes to profiles
-    0x15 "DVD-R/DL sequential recording", 0x2b "DVD+R/DL".
-    Writeable stdio-drives return this profile
+    0x15 "DVD-R/DL sequential recording", 0x43 "BD-RE".
+    Writeable stdio-drives return this profile:
     0xffff "stdio file"
     @param d The drive where the media is inserted.
     @param pno Profile Number as of mmc5r03c.pdf, table 89
@@ -1107,6 +1107,7 @@ off_t burn_disc_available_space(struct burn_drive *d,
 int burn_disc_get_profile(struct burn_drive *d, int *pno, char name[80]);
 
 /** Tells whether a disc can be erased or not
+    @param d The drive to inquire.
     @return Non-zero means erasable
 */
 int burn_disc_erasable(struct burn_drive *d);
@@ -2036,8 +2037,8 @@ int burn_track_get_mode(struct burn_track *track);
 */
 int burn_session_get_hidefirst(struct burn_session *session);
 
-/** Returns the library's version in its parts
-    This is the runtime counterpart of the three build time macros
+/** Returns the library's version in its parts.
+    This is the runtime counterpart of the three build time macros 
     burn_header_version_* below.
     @param major The major version number
     @param minor The minor version number
@@ -2065,12 +2066,54 @@ void burn_version(int *major, int *minor, int *micro);
 */
 #define burn_header_version_major  0
 #define burn_header_version_minor  4
-#define burn_header_version_micro  2
+#define burn_header_version_micro  4
 /** Note:
-    Above version numbers are also recorded in configure.ac and indirectly
-    lead to the reply of burn_version().
-    So the version triples in configure.ac and libburn.h must be kept equal.
-    In future versions the triple of libburn.h will be decisive alone.
+    Above version numbers are also recorded in configure.ac because libtool
+    wants them as parameters at build time.
+    For the library compatibility check BURN_*_VERSION in configure.ac
+    are not decisive. Only the three numbers above do matter.
+*/
+/** Usage discussion:
+
+Some developers of the libburnia project have differing
+opinions how to ensure the compatibility of libaries
+and applications.
+
+It is about whether to use at compile time and at runtime
+the version numbers isoburn_header_version_* provided here.
+Thomas Schmitt advises to use them.
+Vreixo Formoso advises to use other means.
+
+At compile time:
+
+Vreixo Formoso advises to leave proper version matching
+to properly programmed checks in the the application's
+build system, which will eventually refuse compilation.
+
+Thomas Schmitt advises to use the macros defined here
+for comparison with the application's requirements of
+library revisions and to eventually break compilation.
+
+Both advises are combinable. I.e. be master of your
+build system and have #if checks in the source code
+of your application, nevertheless.
+
+At runtime (via *_is_compatible()):
+
+Vreixo Formoso advises to compare the application's
+requirements of library revisions with the runtime
+library. This is to allow runtime libraries which are
+young enough for the application but too old for
+the lib*.h files seen at compile time.
+
+Thomas Schmitt advises to compare the header
+revisions defined here with the runtime library.
+This is to enforce a strictly monotonous chain
+of revisions from app to header to library,
+at the cost of excluding some older libraries.
+
+These two advises are mutually exclusive.
+
 */
 
 
@@ -2146,6 +2189,16 @@ int burn_msgs_submit(int error_code, char msg_text[], int os_errno,
 int burn_text_to_sev(char *severity_name, int *severity_number, int flag);
 
 
+/* ts A80202 : @since 0.4.4 */
+/** Convert a severity number into a severity name
+    @param severity_number The rank number: the higher, the more severe.
+    @param severity_name A name as with burn_msgs_submit(), e.g. "SORRY".
+    @param flag Bitfield for control purposes (unused yet, submit 0)
+*/
+int burn_sev_to_text(int severity_number, char **severity_name, int flag);
+
+
+
 /* ts A70915 */
 /** Replace the messenger object handle of libburn by a compatible handle
     obtained from a related library. 
@@ -2206,7 +2259,7 @@ void burn_set_signal_handling(void *handle, burn_abort_handler_t handler,
                         drive buffer without further data transfer).
     @param flag         Bitfield for control purposes:
                         bit0 = flush the drive buffer after eventual writing
-    @return 1=sucessful , <=0 : number of tranfered bytes * -1
+    @return 1=sucessful , <=0 : number of transfered bytes * -1
 */
 int burn_random_access_write(struct burn_drive *d, off_t byte_address,
                              char *data, off_t data_count, int flag);
