@@ -254,6 +254,8 @@ int libdax_msgs__text_to_sev(char *severity_name, int *severity,
    *severity= LIBDAX_MSGS_SEV_FATAL;
  else if(strncmp(severity_name,"FAILURE",7)==0)
    *severity= LIBDAX_MSGS_SEV_FAILURE;
+ else if(strncmp(severity_name,"MISHAP",6)==0)
+   *severity= LIBDAX_MSGS_SEV_MISHAP;
  else if(strncmp(severity_name,"SORRY",5)==0)
    *severity= LIBDAX_MSGS_SEV_SORRY;
  else if(strncmp(severity_name,"WARNING",7)==0)
@@ -266,10 +268,12 @@ int libdax_msgs__text_to_sev(char *severity_name, int *severity,
    *severity= LIBDAX_MSGS_SEV_UPDATE;
  else if(strncmp(severity_name,"DEBUG",5)==0)
    *severity= LIBDAX_MSGS_SEV_DEBUG;
+ else if(strncmp(severity_name,"ERRFILE",7)==0)
+   *severity= LIBDAX_MSGS_SEV_ERRFILE;
  else if(strncmp(severity_name,"ALL",3)==0)
    *severity= LIBDAX_MSGS_SEV_ALL;
  else {
-   *severity= LIBDAX_MSGS_SEV_NEVER;
+   *severity= LIBDAX_MSGS_SEV_ALL;
    return(0);
  }
  return(1);
@@ -280,7 +284,7 @@ int libdax_msgs__sev_to_text(int severity, char **severity_name,
                              int flag)
 {
  if(flag&1) {
-   *severity_name= "NEVER\nABORT\nFATAL\nFAILURE\nSORRY\nWARNING\nHINT\nNOTE\nUPDATE\nDEBUG\nALL";
+   *severity_name= "NEVER\nABORT\nFATAL\nFAILURE\nMISHAP\nSORRY\nWARNING\nHINT\nNOTE\nUPDATE\nDEBUG\nERRFILE\nALL";
    return(1);
  }
  *severity_name= "";
@@ -292,6 +296,8 @@ int libdax_msgs__sev_to_text(int severity, char **severity_name,
    *severity_name= "FATAL";
  else if(severity>=LIBDAX_MSGS_SEV_FAILURE)
    *severity_name= "FAILURE";
+ else if(severity>=LIBDAX_MSGS_SEV_MISHAP)
+   *severity_name= "MISHAP";
  else if(severity>=LIBDAX_MSGS_SEV_SORRY)
    *severity_name= "SORRY";
  else if(severity>=LIBDAX_MSGS_SEV_WARNING)
@@ -304,6 +310,8 @@ int libdax_msgs__sev_to_text(int severity, char **severity_name,
    *severity_name= "UPDATE";
  else if(severity>=LIBDAX_MSGS_SEV_DEBUG)
    *severity_name= "DEBUG";
+ else if(severity>=LIBDAX_MSGS_SEV_ERRFILE)
+   *severity_name= "ERRFILE";
  else if(severity>=LIBDAX_MSGS_SEV_ALL)
    *severity_name= "ALL";
  else {
