@@ -91,6 +91,8 @@ extern struct libdax_msgs *libdax_messenger;
    ts A70208 : Finally made tests with DVD-R. Worked exactly as new DVD-RW.
    ts A70306 : Implemented DVD+R (always -multi for now)
    ts A70330 : Allowed finalizing of DVD+R.
+   ts A80228 : Made DVD+R/DL support official after nightmorph reported success
+               in http://libburnia-project.org/ticket/13
 */
 
 /* ts A70519 : With MMC commands of data direction FROM_DRIVE:
@@ -306,8 +308,9 @@ int mmc_read_track_info(struct burn_drive *d, int trackno, struct buffer *buf,
 	c.opcode[1] = 1;
 	if(trackno<=0) {
 		if (d->current_profile == 0x1a || d->current_profile == 0x13 ||
-		    d->current_profile == 0x12 )
-			 /* DVD+RW , DVD-RW restricted overwrite , DVD-RAM */
+		    d->current_profile == 0x12 || d->current_profile == 0x43)
+			 /* DVD+RW , DVD-RW restricted overwrite , DVD-RAM
+			    BD-RE */
 			trackno = 1;
 		else if (d->current_profile == 0x10 ||
 			 d->current_profile == 0x11 ||
@@ -349,7 +352,7 @@ int mmc_get_nwa(struct burn_drive *d, int trackno, int *lba, int *nwa)
 	*nwa = mmc_four_char_to_int(data + 12);
 	num = mmc_four_char_to_int(data + 16);
 	if (d->current_profile == 0x1a || d->current_profile == 0x13 ||
-	    d->current_profile == 0x12) {
+	    d->current_profile == 0x12 || d->current_profile == 0x43) {
 		 /* overwriteable */
 		*lba = *nwa = num = 0;
 	} else if (!(data[7]&1)) {
@@ -1422,6 +1425,7 @@ static int mmc_read_disc_info_al(struct burn_drive *d, int *alloc_len)
 		disc_status = 2; /* always full and finalized */
 		d->erasable = 0; /* never erasable */
 	}
+
 	switch (disc_status) {
 	case 0:
 		d->toc_entries = 0;
@@ -1445,6 +1449,15 @@ static int mmc_read_disc_info_al(struct burn_drive *d, int *alloc_len)
 		break;
 	}
 
+	/* ts A80207 : DVD +/- R DL can normally be read but not be written */
+	if((d->current_profile == 0x2b || d->current_profile == 0x15) &&
+	   !d->current_is_supported_profile) {
+		if(d->status == BURN_DISC_APPENDABLE)
+			d->status = BURN_DISC_FULL;
+		d->erasable = 0; /* never erasable */
+		d->current_is_supported_profile = 1;
+	}
+
 	if ((d->current_profile != 0 || d->status != BURN_DISC_UNREADY) 
 		&& ! d->current_is_supported_profile) {
 		if (!d->silent_on_scsi_error) {
@@ -1480,7 +1493,7 @@ static int mmc_read_disc_info_al(struct burn_drive *d, int *alloc_len)
 	   ts A70112 : same for DVD-RAM
 	*/
 	if (d->current_profile == 0x1a || d->current_profile == 0x13 ||
-	    d->current_profile == 0x12)
+	    d->current_profile == 0x12 || d->current_profile == 0x43)
 		d->status = BURN_DISC_BLANK;
 
 	if (d->status == BURN_DISC_BLANK) {
@@ -2094,7 +2107,8 @@ static int mmc_get_configuration_al(struct burn_drive *d, int *alloc_len)
 		d->current_is_supported_profile = 1;
 #endif
 #ifdef Libburn_support_dvd_raM
-	if (cp == 0x12)
+	if (cp == 0x12 || (cp == 0x43 && burn_support_untested_profiles))
+							/* DVD-RAM , BD-RE */
 		d->current_is_supported_profile = 1;
 #endif
 #ifdef Libburn_support_dvd_r_seQ
@@ -2104,8 +2118,7 @@ static int mmc_get_configuration_al(struct burn_drive *d, int *alloc_len)
 		d->current_is_supported_profile = 1;
 #endif
 #ifdef Libburn_support_dvd_plus_R
-	if (cp == 0x1b || (cp == 0x2b && burn_support_untested_profiles))
-						/* DVD+R , DVD+R/DL */
+	if (cp == 0x1b || cp == 0x2b) /* DVD+R , DVD+R/DL */
 		d->current_is_supported_profile = 1;
 #endif
 
@@ -2994,8 +3007,9 @@ int mmc_compose_mode_page_5(struct burn_drive *d,
 		pd[13] = 16;
 
 	} else if (d->current_profile == 0x1a || d->current_profile == 0x1b ||
-	           d->current_profile == 0x2b || d->current_profile == 0x12) {
-		/* not with DVD+R[W][/DL] or DVD-RAM */;
+	           d->current_profile == 0x2b || d->current_profile == 0x12 ||
+		   d->current_profile == 0x43) {
+		/* not with DVD+R[W][/DL] or DVD-RAM or BD-RE */;
 		return 0;
 	} else {
 		/* Traditional setup for CD */
