@@ -325,6 +325,19 @@ int burn_read_data(struct burn_drive *d, off_t byte_address,
 	char msg[81], *wpt;
 	struct buffer buf;
 
+/*
+#define Libburn_read_data_adr_logginG 1
+*/
+#ifdef Libburn_read_data_adr_logginG
+	static FILE *log_fp= NULL;
+
+	if(log_fp == NULL)
+		log_fp = fopen("/tmp/burn_read_data_log", "a");
+	if(log_fp!=NULL)
+		fprintf(log_fp, "%d\n", (int) (byte_address / 2048));
+#endif /* Libburn_read_data_logginG */
+
+
 	*data_count = 0;
 	sose_mem = d->silent_on_scsi_error;
 
@@ -375,7 +388,10 @@ int burn_read_data(struct burn_drive *d, off_t byte_address,
 #define O_LARGEFILE 0
 #endif
 
-		fd = open(d->devname, O_RDONLY | O_LARGEFILE);
+		fd = d->stdio_fd;
+		if (fd < 0)
+			d->stdio_fd = fd =
+				open(d->devname, O_RDONLY | O_LARGEFILE);
 		if (fd == -1) {
 			if (errno != ENOENT  || !(flag & 2))
 				libdax_msgs_submit(libdax_messenger,
@@ -448,6 +464,14 @@ int burn_read_data(struct burn_drive *d, off_t byte_address,
 				wpt += 2048;
 				*data_count += 2048;
 			}
+
+			libdax_msgs_submit(libdax_messenger,
+				 d->global_index,
+				 0x00020000,
+				 LIBDAX_MSGS_SEV_DEBUG, LIBDAX_MSGS_PRIO_HIGH,
+				 "burn_read_data() returns 0",
+				 0, 0);
+
 			ret = 0; goto ex;
 		}
 		memcpy(wpt, d->buffer->data, cpy_size);
@@ -457,8 +481,10 @@ int burn_read_data(struct burn_drive *d, off_t byte_address,
 
 	ret = 1;
 ex:;
+/* <<< let it open until drive is given up or writing shall happen
 	if (fd != -1)
 		close(fd);
+*/
 	d->buffer = NULL;
 	d->busy = BURN_DRIVE_IDLE;
 	return ret;
