@@ -114,13 +114,21 @@ struct burn_format_descr {
 	off_t size;
 
 	/* the Type Dependent Parameter (usually the write alignment size) */
-	unsigned tdp;
+	unsigned int tdp;
 };
 
 
 /** Gets initialized in enumerate_common() and burn_drive_register() */
 struct burn_drive
 {
+	/* ts A70902:
+		0=null-emulation
+		1=MMC drive ,
+		2=stdio random read-write
+		3=stdio sequential write-only
+	*/
+	int drive_role;
+
 	int bus_no;
 	int host;
 	int id;
@@ -172,9 +180,12 @@ struct burn_drive
 	*/
 	int current_feat2fh_byte4;
 
-	/* ts A70114 : wether a DVD-RW media holds an incomplete session
+	/* ts A70114 : whether a DVD-RW media holds an incomplete session
 	               (which could need closing after write) */
 	int needs_close_session;
+	/* ts A71003 : whether a random write operation was done and no
+	               synchronize chache has happened yet */
+	int needs_sync_cache;
 
 	/* ts A61218 from 51h READ DISC INFORMATION */
 	int bg_format_status; /* 0=needs format start, 1=needs format restart*/
@@ -182,7 +193,7 @@ struct burn_drive
 	/* ts A70108 from 23h READ FORMAT CAPACITY mmc5r03c.pdf 6.24 */
 	int format_descr_type;      /* 1=unformatted, 2=formatted, 3=unclear */
 	off_t format_curr_max_size;  /* meaning depends on format_descr_type */
-	unsigned format_curr_blsas;  /* meaning depends on format_descr_type */
+	unsigned int format_curr_blsas;  /* dito */
 	int best_format_type;
 	off_t best_format_size;
 
@@ -196,6 +207,8 @@ struct burn_drive
 	/* ts A61106 */
 	int silent_on_scsi_error;
 
+	int stdio_fd;
+
 	int nwa;		/* next writeable address */
 	int alba;		/* absolute lba */
 	int rlba;		/* relative lba in section */
@@ -229,18 +242,24 @@ struct burn_drive
 	int pbf_altered;
 	int wait_for_buffer_free;
 	int nominal_write_speed;
-	unsigned wfb_min_usec;
-	unsigned wfb_max_usec;
-	unsigned wfb_timeout_sec;
-	unsigned wfb_min_percent;
-	unsigned wfb_max_percent;
-	unsigned pessimistic_writes;
-	unsigned waited_writes;
-	unsigned waited_tries;
-	unsigned waited_usec;
+	unsigned int wfb_min_usec;
+	unsigned int wfb_max_usec;
+	unsigned int wfb_timeout_sec;
+	unsigned int wfb_min_percent;
+	unsigned int wfb_max_percent;
+	unsigned int pessimistic_writes;
+	unsigned int waited_writes;
+	unsigned int waited_tries;
+	unsigned int waited_usec;
 
 	volatile int cancel;
 	volatile enum burn_drive_status busy;
+
+	/* ts A70929 */
+	pid_t thread_pid;
+	int thread_pid_valid;
+
+
 /* transport functions */
 	int (*grab) (struct burn_drive *);
 	int (*release) (struct burn_drive *);
@@ -320,6 +339,11 @@ struct burn_drive
 	/* mmc5r03c.pdf 6.24 : get list of available formats */
 	int (*read_format_capacities) (struct burn_drive *d, int top_wanted);
 
+	/* ts A70812 */
+	/* mmc5r03c.pdf 6.15 : read data sectors (start and amount in LBA) */
+	int (*read_10) (struct burn_drive *d, int start, int amount,
+	                struct buffer *buf);
+
 };
 
 /* end of generic 'drive' data structures */
