@@ -6,10 +6,17 @@
 
 #include <unistd.h>
 #include <stdio.h>
+#include <signal.h>
 #include <assert.h>
 
 static struct burn_drive_info *drives;
 static unsigned int n_drives;
+int NEXT;
+
+static void catch_int ()
+{
+	NEXT = 1;
+}
 
 static void poll_drive(int d)
 {
@@ -29,8 +36,8 @@ static void poll_drive(int d)
 	while ((s = burn_disc_get_status(drives[d].drive))
 	       == BURN_DISC_UNREADY)
 		usleep(1000);
-
-	while (1) {
+	
+	while (NEXT == 0) {
 		sleep(2);
 		mmc_get_event(drives[d].drive);
 	}
@@ -39,6 +46,9 @@ static void poll_drive(int d)
 
 int main()
 {
+    	int i;
+	struct sigaction newact;
+	struct sigaction oldact;
 	fprintf(stderr, "Initializing library...");
 	if (burn_initialize())
 		fprintf(stderr, "Success\n");
@@ -50,8 +60,18 @@ int main()
 	fprintf(stderr, "Scanning for devices...");
 	while (!burn_drive_scan(&drives, &n_drives)) ;
 	fprintf(stderr, "Done\n");
+	if (!drives) {
+	    	printf("No burner found\n");
+		return 1;
+	} 
 
-	poll_drive(2);
+	newact.sa_handler = catch_int;
+	sigaction(SIGINT, &newact, &oldact);
+	for (i = 0; i < n_drives; i++) {
+	    NEXT=0;
+	    poll_drive(i);
+	}
+	sigaction(SIGINT, &oldact, NULL);
 	burn_drive_info_free(drives);
 	burn_finish();
 	return 0;
